<?php
namespace MASCOTCOREINDUSTRYEE\Shortcodes\InfoBanner;

use MASCOTCOREINDUSTRYEE\Shortcodes\Lib;

/**
 * class SC_Info_Banner
 * @package MASCOTCOREINDUSTRYEE\Shortcodes\InfoBanner;
 */
class SC_Info_Banner implements Lib\Mascot_Core_Industryee_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_info_banner';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {

		if(function_exists('vc_map')) {
			$group_subtitle_options = esc_html__( 'Sub Title', 'mascot-core' );
			$group_title_options = esc_html__( 'Title', 'mascot-core' );
			$group_button_options = esc_html__( 'Link Options', 'mascot-core' );
			$vc_map = array(
				'name'		=> esc_html__( 'Info Banner', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> 'by TM',
				'icon'		=> 'mascot-vc-icons vc-icon-info-banner',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),


					array(
						'type'			=> 'attach_image',
						"heading"		=> esc_html__( "Background Image", 'mascot-core' ),
						"param_name"	=> "bg_image",
						"description"	=> esc_html__( 'Upload the before image.', 'mascot-core' ),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Background Image Size", 'mascot-core' ),
						"param_name"	=> "bg_image_size",
						'description'   => '',
						'value'			=> mascot_core_industryee_get_available_image_sizes_for_vc(),
						'std'			=> 'large',
					),
					array(
						'type'			=> 'colorpicker',
						"heading"		=> esc_html__( "Image Overlay Color", 'mascot-core' ),
						"param_name"	=> "overlay_color",
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Text Alignment", 'mascot-core' ),
						"param_name"	=> "text_alignment",
						"description"	=> "",
						'value'			=> mascot_core_industryee_text_alignment_list(),
						'save_always'   => true,
					),





					//title
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Title Custom CSS Class", 'mascot-core' ),
						"param_name"	=> "title_custom_css_class",
						"description"	=> esc_html__( 'To style Title.', 'mascot-core' ),
						'admin_label'   => true,
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Title", 'mascot-core' ),
						"param_name"	=> "title",
						'admin_label'   => true,
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Title Tag", 'mascot-core' ),
						"param_name"	=> "title_tag",
						'description'   => esc_html__( 'Default: H3', 'mascot-core' ),
						'value'			=> mascot_core_industryee_heading_tag_list(),
						'std'			=> 'h3',
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'colorpicker',
						"heading"		=> esc_html__( "Text Color", 'mascot-core' ),
						"param_name"	=> "title_text_color",
						'description'	=> '',
						'group'			=> $group_title_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Font Size", 'mascot-core' ),
						"param_name"	=> "title_font_size",
						"description"	=> "",
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Line Height", 'mascot-core' ),
						"param_name"	=> "title_line_height",
						"description"	=> "",
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Margin Top (px)", 'mascot-core' ),
						"param_name"	=> "title_mt",
						"description"	=> "",
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Letter Spacing", 'mascot-core' ),
						"param_name"	=> "title_letter_spacing",
						"description"	=> "",
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Font Style", 'mascot-core' ),
						"param_name"	=> "title_font_style",
						"description"	=> "",
						'value'			=> mascot_core_industryee_vc_font_style_list(),
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Font Weight", 'mascot-core' ),
						"param_name"	=> "title_font_weight",
						"description"	=> "",
						'value'			=> mascot_core_industryee_vc_font_weight_list(),
						'group'			=> $group_title_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Text Transform", 'mascot-core' ),
						"param_name"	=> "title_text_transform",
						"description"	=> "",
						'value'			=> mascot_core_industryee_vc_text_transform_list(),
						'group'			=> $group_title_options
					),





					//subtitle
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Sub Title Custom CSS Class", 'mascot-core' ),
						"param_name"	=> "subtitle_custom_css_class",
						"description"	=> esc_html__( 'To style Sub Title.', 'mascot-core' ),
						'admin_label'   => true,
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Sub Title", 'mascot-core' ),
						"param_name"	=> "subtitle",
						'admin_label'   => true,
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Sub Title Tag", 'mascot-core' ),
						"param_name"	=> "subtitle_tag",
						'description'   => esc_html__( 'Default: H5', 'mascot-core' ),
						'value'			=> mascot_core_industryee_heading_tag_list(),
						'std'			=> 'h5',
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'colorpicker',
						"heading"		=> esc_html__( "Text Color", 'mascot-core' ),
						"param_name"	=> "subtitle_text_color",
						'description'	=> '',
						'group'			=> $group_subtitle_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Font Size", 'mascot-core' ),
						"param_name"	=> "subtitle_font_size",
						"description"	=> "",
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Line Height", 'mascot-core' ),
						"param_name"	=> "subtitle_line_height",
						"description"	=> "",
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Margin Top (px)", 'mascot-core' ),
						"param_name"	=> "subtitle_mt",
						"description"	=> "",
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Letter Spacing", 'mascot-core' ),
						"param_name"	=> "subtitle_letter_spacing",
						"description"	=> "",
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Font Style", 'mascot-core' ),
						"param_name"	=> "subtitle_font_style",
						"description"	=> "",
						'value'			=> mascot_core_industryee_vc_font_style_list(),
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Font Weight", 'mascot-core' ),
						"param_name"	=> "subtitle_font_weight",
						"description"	=> "",
						'value'			=> mascot_core_industryee_vc_font_weight_list(),
						'group'			=> $group_subtitle_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Text Transform", 'mascot-core' ),
						"param_name"	=> "subtitle_text_transform",
						"description"	=> "",
						'value'			=> mascot_core_industryee_vc_text_transform_list(),
						'group'			=> $group_subtitle_options
					),

					


					//link
					array(
						'type'			=> 'vc_link',
						'heading'		=> esc_html__( 'Link URL', 'mascot-core' ),
						'param_name'	=> 'link_url',
						'group'			=> $group_button_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Link Margin Top (px)", 'mascot-core' ),
						"param_name"	=> "link_mt",
						"description"	=> "",
						'group'			=> $group_button_options
					),
					//button options
					mascot_core_industryee_get_button_arraylist( 1, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 2, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 3, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 4, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 5, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 6, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 7, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 8, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 9, $group_button_options ),
					mascot_core_industryee_get_button_arraylist( 10, $group_button_options ),

					mascot_core_industryee_vc_add_css_editor(),
				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_industryee_sc_info_banner_vc_map_modifier') ) {
				mascot_core_industryee_sc_info_banner_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_industryee_sc_info_banner_render') && function_exists('vc_map') ) {
			return mascot_core_industryee_sc_info_banner_render( $attr, $content );
		}
		
	}
}